@@ -29,7 +29,7 @@ token_from_auth = gl.private_token
 gl = gitlab.Gitlab.from_config(config_files=['/tmp/python-gitlab.cfg'])
 assert(token_from_auth == gl.private_token)
 gl.auth()
-assert(isinstance(gl.user, gitlab.objects.CurrentUser))
+assert(isinstance(gl.user, gitlab.v3.objects.CurrentUser))
 
 # settings
 settings = gl.settings.get()
@@ -100,8 +100,12 @@ user2 = gl.users.create({'email': 'user2@test.com', 'username': 'user2',
 group1 = gl.groups.create({'name': 'group1', 'path': 'group1'})
 group2 = gl.groups.create({'name': 'group2', 'path': 'group2'})
 
-assert(len(gl.groups.list()) == 2)
+p_id = gl.groups.search('group2')[0].id
+group3 = gl.groups.create({'name': 'group3', 'path': 'group3', 'parent_id': p_id})
+
+assert(len(gl.groups.list()) == 3)
 assert(len(gl.groups.search("1")) == 1)
+assert(group3.parent_id == p_id)
 
 group1.members.create({'access_level': gitlab.Group.OWNER_ACCESS,
                        'user_id': user1.id})
@@ -141,7 +145,7 @@ sudo_project = gl.projects.create({'name': 'sudo_project'}, sudo=user1.name)
 
 assert(len(gl.projects.all()) == 4)
 assert(len(gl.projects.owned()) == 2)
-assert(len(gl.projects.search("admin")) == 1)
+assert(len(gl.projects.list(search="admin")) == 1)
 
 # test pagination
 l1 = gl.projects.list(per_page=1, page=1)
